Module session

Module session 

CRV Session Manager

Manages CRV sessions as directed acyclic graphs (DAGs), where each session progresses through stages I-VI. Provides cross-session convergence analysis to find agreement between multiple viewers targeting the same coordinate.

Architecture

Each session is a DAG of stage entries. Cross-session convergence is computed by finding entries with high embedding similarity across different sessions targeting the same coordinate.

Structs

CrvSessionManager
CRV Session Manager: coordinates all stage encoders and manages sessions.