CrvSessionManager

Struct CrvSessionManager 

pub struct CrvSessionManager { /* private fields */ }
CRV Session Manager: coordinates all stage encoders and manages sessions.

Implementations

Source

impl CrvSessionManager

pub fn new(config: CrvConfig) -> Self

Create a new session manager with the given configuration.

pub fn create_session( &mut self, session_id: SessionId, coordinate: TargetCoordinate, ) -> CrvResult<()>

Create a new session for a given target coordinate.

pub fn add_stage_i( &mut self, session_id: &str, data: &StageIData, ) -> CrvResult<Vec<f32>>

Add Stage I data to a session.

pub fn add_stage_ii( &mut self, session_id: &str, data: &StageIIData, ) -> CrvResult<Vec<f32>>

Add Stage II data to a session.

pub fn add_stage_iii( &mut self, session_id: &str, data: &StageIIIData, ) -> CrvResult<Vec<f32>>

Add Stage III data to a session.

pub fn add_stage_iv( &mut self, session_id: &str, data: &StageIVData, ) -> CrvResult<Vec<f32>>

Add Stage IV data to a session.

pub fn run_stage_v( &mut self, session_id: &str, probe_queries: &[(&str, u8, Vec<f32>)], k: usize, ) -> CrvResult<StageVData>

Run Stage V interrogation on a session.

Probes the accumulated session data with specified queries.

pub fn run_stage_vi(&mut self, session_id: &str) -> CrvResult<StageVIData>

Run Stage VI composite modeling on a session.

pub fn find_convergence( &self, coordinate: &str, min_similarity: f32, ) -> CrvResult<ConvergenceResult>

Find convergence across multiple sessions targeting the same coordinate.

This is the core multi-viewer matching operation: given sessions from different viewers targeting the same coordinate, find which aspects of their signal line data converge (agree).

pub fn get_session_embeddings( &self, session_id: &str, ) -> CrvResult<Vec<CrvSessionEntry>>

Get all embeddings for a session.

pub fn session_entry_count(&self, session_id: &str) -> usize

Get the number of entries in a session.

pub fn session_count(&self) -> usize

Get the number of active sessions.

pub fn remove_session(&mut self, session_id: &str) -> bool

Remove a session.

pub fn stage_i_encoder(&self) -> &StageIEncoder

Get access to the Stage I encoder for direct operations.

pub fn stage_ii_encoder(&self) -> &StageIIEncoder

Get access to the Stage II encoder for direct operations.

pub fn stage_iv_encoder(&self) -> &StageIVEncoder

Get access to the Stage IV encoder for direct operations.

pub fn stage_v_engine(&self) -> &StageVEngine

Get access to the Stage V engine for direct operations.

pub fn stage_vi_modeler(&self) -> &StageVIModeler

Get access to the Stage VI modeler for direct operations.